@@ -11,7 +11,7 @@ import multiprocessing.dummy
 class ResourcesExhausted(StopIteration):
     """Indicates an exhaustion of the specified budget (not an error).
 
-    Inherits from StopIteration.
+    Inherits from :class:`StopIteration`.
 
     """
     def __init__(self, resource=None):
@@ -302,7 +302,7 @@ class Cache(Problem):
     potentially occurring duplicates of previously seen solutions. This
     is especially useful in discrete search spaces.
 
-    .. warning:: This wrapper lets you limit the number of true
+    .. note:: This wrapper lets you limit the number of true
         evaluations, but not the number of 'virtual' ones. This may lead
         to infinite loops if your optimization algorithm contains bugs.
         For limiting the number of virtual evaluations, a construct such
@@ -465,7 +465,7 @@ class BoundConstraintsChecker:
 
         Parameters
         ----------
-        bounds : tuple of two sequences
+        bounds : tuple of sequence
             The first sequence contains the lower bounds, the second
             sequence contains the upper bounds for each variable.
         previous_preprocessor : callable, optional
@@ -633,7 +633,7 @@ class BoundConstraintsRepair:
 
         Parameters
         ----------
-        bounds : tuple of two sequences
+        bounds : tuple of sequence
             The first sequence contains the lower bounds, the second
             sequence contains the upper bounds for each variable.
         repair_modes : sequence
@@ -685,17 +685,14 @@ class BoundConstraintsRepair:
 
 
 class TestProblem(Problem):
-    """Abstract base class for artificial test problems.
+    """Abstract base class for artificial test problems."""
 
-    """
     def get_optimal_solutions(self, max_number=None):
         """Return globally optimal or Pareto-optimal solutions.
 
         This is an abstract method. Implementations must be deterministic.
         In the multi-objective case, the generated solutions should be
-        evenly distributed over the whole Pareto-set. Furthermore, if the
-        problem is bi-objective, the solutions should be ordered by
-        objective values.
+        evenly distributed over the whole Pareto-set.
 
         """
         raise NotImplementedError("Optimal solutions are unknown.")
